@@ -1,4 +1,4 @@
-# Copyright (C) 2008-2009 Adam Olsen
+# Copyright (C) 2008-2010 Adam Olsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -74,7 +74,7 @@ class Panel(gobject.GObject):
     def __del__(self):
         import xlgui
         try:
-            xlgui.controller().remove_panel(self._child)
+            xlgui.get_controller().remove_panel(self._child)
         except ValueError:
             pass
 
